//-------------------------------------------------------------------------------------
//	FILE:			PulsesTest_DCAC-PWM_Cnf.c
//
//	Description:	Driver configuration to support a full bridge or a half bridge
//					Based on TI's original code
//
//	Version: 		1.0
//
// The function call is:
//
// 		PWM_PFC2PhiL_CNF(int16 n, int16 period)
//
// Function arguments defined as:
//-------------------------------
// n = 		Target ePWM module, 1,2,...16.  e.g. if n=2, then target is ePWM2
// period = PWM period in Sysclks for Up-Down PWM configuration
//
//-------------------------------------------------------------------------------------
#include "allHeaderIncludes.h"
#include "DSP2803x_EPWM_defines.h" 		// useful defines specific to EPWM 


//---------------------------------------------------------------------------
// Used to indirectly access all EPWM modules
volatile struct EPWM_REGS *ePWM[] =
 				  { &EPwm1Regs,			//intentional: (ePWM[0] not used)
				  	&EPwm1Regs,
					&EPwm2Regs,
					&EPwm3Regs,
					&EPwm4Regs,
					#if (!DSP2802x_DEVICE_H)
					&EPwm5Regs,
					&EPwm6Regs,
					#if (DSP2803x_DEVICE_H || DSP2804x_DEVICE_H)
					&EPwm7Regs,
					#if (DSP2804x_DEVICE_H)
					&EPwm8Regs
					#endif
					#endif
					#endif
				  };


void PWM_Config(int16 n, int16 Period)
{
	//Time Base SubModule Register
	(*ePWM[n]).TBCTL.bit.PRDLD = TB_IMMEDIATE;	// set Immediate load
	(*ePWM[n]).TBPRD= (Period>>1);
	(*ePWM[n]).TBPHS.half.TBPHS =0;
	(*ePWM[n]).TBCTR = 0;
	(*ePWM[n]).TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;
	(*ePWM[n]).TBCTL.bit.HSPCLKDIV = TB_DIV1;
	(*ePWM[n]).TBCTL.bit.CLKDIV = TB_DIV1;
	(*ePWM[n]).TBCTL.bit.PHSEN = TB_DISABLE;
	(*ePWM[n]).TBCTL.bit.SYNCOSEL = TB_CTR_ZERO; // sync "down-stream"
	
	// Counter compare submodule registers
	(*ePWM[n]).CMPCTL.bit.LOADAMODE = CC_CTR_PRD;
	(*ePWM[n]).CMPCTL.bit.LOADBMODE = CC_CTR_PRD;
	(*ePWM[n]).CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	(*ePWM[n]).CMPCTL.bit.SHDWBMODE = CC_SHADOW;

	// Action Qualifier SubModule Registers
#if FULL_BRIDGE==1
	(*ePWM[n]).AQCTLA.bit.CAU = AQ_CLEAR;
	(*ePWM[n]).AQCTLA.bit.CAD = AQ_SET;
#else
	#if HALF_BRIDGE_MAIN_SWITCH == 1
	(*ePWM[n]).AQCTLA.bit.CAU = AQ_CLEAR;
	(*ePWM[n]).AQCTLA.bit.CAD = AQ_SET;
	#endif
	#if HALF_BRIDGE_MAIN_SWITCH == 0
	(*ePWM[n]).AQCTLA.bit.CAU = AQ_SET;
	(*ePWM[n]).AQCTLA.bit.CAD = AQ_CLEAR;
	#endif
#endif

	// Deadband SubModule Registers
	(*ePWM[n]).DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; //Both rising and falling edge
	(*ePWM[n]).DBCTL.bit.POLSEL = DB_ACTV_HIC;	// Active high complementary

	(*ePWM[n]).DBFED = 7;//2						// Deadtime is ~33ns @ 60MHz
	(*ePWM[n]).DBRED = 7;//2

	
	// Configure the Tripzone Registers
	EALLOW;	
//===========================================================================
// TZA events can force EPWMxA
// TZB events can force EPWMxB
	(*ePWM[n]).TZCTL.bit.TZA = TZ_FORCE_LO; // EPWM1A will go low
	(*ePWM[n]).TZCTL.bit.TZB = TZ_FORCE_LO; // EPWM1B will go low
	(*ePWM[n]).TZFRC.bit.OST = 1;			// Turn off the PWM

	EDIS;
	(*ePWM[n]).CMPA.half.CMPA = 0;		   //Initialize the CMP register
}


